#!/bin/sh

# ------------------------------------------------------------
# Company:  Software- und Organisations-Service GmbH
# Purpose:  Start script for JS7 Converter
# Platform: AIX, Linux, MacOS: bash, ksh, zsh, dash
# ------------------------------------------------------------
#
# Example:  ./js7_convert_js1.sh --input-dir=/var/sos-berlin.com/jobscheduler/config/live --output-dir=/tmp/output --report-dir=/tmp/report --archive=/tmp/js7_converted_js1.tar.gz

set -e

# ------------------------------
# Initialize variables
# ------------------------------

js7_converter_home=$(dirname "$0")
js7_converter_libdir="${js7_converter_home}/lib"
js7_converter_default_output_dir="${js7_converter_home}/output"
js7_converter_default_report_dir="${js7_converter_home}/report"
js7_converter_default_archive="${js7_converter_home}/js7_converted_js1.tar.gz"
js7_converter_default_config="${js7_converter_home}/js7_convert_js1.config"
java_bin=

get_timezone()
{
    if [ -f "${js7_converter_libdir}/classes/DefaultTimeZone.class" ]
    then
        "${JAVABIN}" -classpath "${js7_converter_libdir}/classes" DefaultTimeZone 2>/dev/null || echo "Etc/UTC"
    else
        echo "Etc/UTC"
    fi
}

Usage()
{
    >&2 echo ""
    >&2 echo "Usage: $(basename "$0") [Options] [Switches]"
    >&2 echo ""
    >&2 echo "  Options:"
    >&2 echo "    --input-dir=<location of input directory>                         | required argument"
    >&2 echo "    --output-dir=<locatin of output directory>                        | default: $js7_converter_default_output_dir"
    >&2 echo "    --report-dir=<location of report directory>                       | default: $js7_converter_default_report_dir"
    >&2 echo "    --archive=<location of resulting .tar.gz archive for JS7 import>  | default: $js7_converter_default_archive"
    >&2 echo "    --config=<location of config file>                                | default: $js7_converter_default_config"
    >&2 echo "  Switches:"
    >&2 echo "    -h | --help                                                       | displays usage"
    >&2 echo ""
}

# ------------------------------
# Process command line options
# ------------------------------

Arguments()
{
    for option in "$@"
    do
        case "$option" in
            -h|--help)          Usage
                                exit
                                ;;
            --input-dir=*)      js7_converter_input_dir=$(echo "$option" | sed 's/--input-dir=//' | sed 's/^"//' | sed 's/"$//' | sed 's/^\(.*\)\/$/\1/')
                                ;;
            --output-dir=*)     js7_converter_output_dir=$(echo "$option" | sed 's/--output-dir=//' | sed 's/^"//' | sed 's/"$//' | sed 's/^\(.*\)\/$/\1/')
                                ;;
            --report-dir=*)     js7_converter_report_dir=$(echo "$option" | sed 's/--report-dir=//' | sed 's/^"//' | sed 's/"$//' | sed 's/^\(.*\)\/$/\1/')
                                ;;
            --archive=*)        js7_converter_archive=$(echo "$option" | sed 's/--archive=//' | sed 's/^"//' | sed 's/"$//')
                                ;;
            --config=*)         js7_converter_config=$(echo "$option" | sed 's/--config=//' | sed 's/^"//' | sed 's/"$//')
                                ;;
            *)                  >&2 echo "unknown option: $option"
                                Usage
                                exit 1
                                ;;
        esac
    done

    if [ -z "$js7_converter_input_dir" ]
    then
        echo "...option --input-dir is missing"
        echo "...please specify the --input-dir=<directory> option with an existing directory for JS1 scheduling *.xml files"
        Usage
        exit 1
    fi

    if [ ! -d "$js7_converter_input_dir" ]
    then
        echo "...could not find input directory: $js7_converter_input_dir"
        echo "...please specify the --input-dir=<directory> option with an existing directory for JS1 scheduling *.xml files"
        Usage
        exit 1
    fi

    if [ -z "$js7_converter_config" ]
    then
        js7_converter_config="$js7_converter_default_config"
    fi

    if [ ! -f "$js7_converter_config" ]
    then
        echo "...could not find configuration file: $js7_converter_config"
        echo "...please specify the --config=<file> option with an existing configuration file"
        Usage
        exit 1
    fi

    if [ -z "$js7_converter_output_dir" ]
    then
        js7_converter_output_dir="$js7_converter_default_output_dir"
    fi

    if [ ! -d "$js7_converter_output_dir" ]
    then
        mkdir -p "$js7_converter_output_dir"
    fi

    if [ -z "$js7_converter_report_dir" ]
    then
        js7_converter_report_dir="$js7_converter_default_report_dir"
    fi

    if [ ! -d "$js7_converter_report_dir" ]
    then
        mkdir -p "$js7_converter_report_dir"
    fi

    if [ -z "$js7_converter_archive" ]
    then
        js7_converter_archive="$js7_converter_default_archive"
    fi
}

# ------------------------------
# Perform converion
# ------------------------------

Process()
{
    java_bin=$(which java 2>/dev/null || echo "")
    test -n "$JAVA_HOME" && test -x "$JAVA_HOME/bin/java" && java_bin="$JAVA_HOME/bin/java"
    if [ -z "$java_bin" ]
    then
        echo "could not identify Java environment, please set JAVA_HOME variable"
        exit 2
    fi

    if [ -z "$js7_converter_tz" ]
    then
        js7_converter_tz="$(get_timezone)"
    fi

    "${java_bin}" -Xmx256m -classpath "${js7_converter_libdir}/sos/*:${js7_converter_libdir}/3rd-party/*:${js7_converter_libdir}/3rd-party/compress/*:${js7_converter_libdir}/3rd-party/log/*:${js7_converter_libdir}/3rd-party/json/*:${js7_converter_libdir}/3rd-party/csv/*:${js7_converter_libdir}" com.sos.js7.converter.js1.JS12JS7ConverterMain --input="${js7_converter_input_dir}" --output-dir="${js7_converter_output_dir}" --report-dir="${js7_converter_report_dir}" --config="${js7_converter_config}" --archive="${js7_converter_archive}"
}

# ------------------------------
# Cleanup temporary resources
# ------------------------------

End()
{
    unset js7_converter_home
    unset js7_converter_libdir
    unset js7_converter_default_output_dir
    unset js7_converter_default_report_dir
    unset js7_converter_default_archive
    unset js7_converter_default_config
    unset java_bin

    set +e
}

# ------------------------------
# Enable trap and start
# ------------------------------

trap 'End EXIT' EXIT
trap 'End SIGTERM' TERM
trap 'End SIGINT' INT

Arguments "$@"
Process
